==> haskell-hslua-module-system-0.2.1-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hslua-module-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hslua-module-system
version: 0.2.1
id: hslua-module-system-0.2.1-KNEJx6tYRSI8ci69boU1zQ
key: hslua-module-system-0.2.1-KNEJx6tYRSI8ci69boU1zQ
license: MIT
copyright: Albert Krewinkel <albert+hslua@zeitkraut.de>
maintainer: albert+hslua@zeitkraut.de
author: Albert Krewinkel
homepage: https://github.com/hslua/hslua-module-system
synopsis: Lua module wrapper around Haskell'\''s System module.
description:
    Provides access to system information and functionality
    to Lua scripts via Haskell'\''s `System` module.
    .
    Intended usage for this package is to preload it by adding
    the loader function to `package.preload`. Note that the
    Lua `package` library must have already been loaded before
    the loader can be added.
category: Foreign
abi: a5e915edb4d3111d2412af9936093a67
exposed: True
exposed-modules:
    Foreign.Lua.Module.System
hidden-modules: Foreign.Lua.Module.SystemUtils
import-dirs: /usr/lib/ghc-8.6.5/site-local/hslua-module-system-0.2.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/hslua-module-system-0.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hslua-module-system-0.2.1
hs-libraries: HShslua-module-system-0.2.1-KNEJx6tYRSI8ci69boU1zQ
depends:
    base-4.12.0.0 containers-0.6.0.1 directory-1.3.3.0
    exceptions-0.10.2-EJs0RkZsum56ksbfDqbl1F
    hslua-1.0.3.1-8zBO4UBCHkEGH1uDk7gEh8
    temporary-1.3-CFCgitssjB1JHRoe7RSBPx
haddock-interfaces: /usr/share/doc/haskell-hslua-module-system/html/hslua-module-system.haddock
haddock-html: /usr/share/doc/haskell-hslua-module-system/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-system-0.2.1-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hslua-module-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hslua-module-system
version: 0.2.1
id: hslua-module-system-0.2.1-HzvfcWKmaLTAidtbC4JDQV
key: hslua-module-system-0.2.1-HzvfcWKmaLTAidtbC4JDQV
license: MIT
copyright: Albert Krewinkel <albert+hslua@zeitkraut.de>
maintainer: albert+hslua@zeitkraut.de
author: Albert Krewinkel
homepage: https://github.com/hslua/hslua-module-system
synopsis: Lua module wrapper around Haskell'\''s System module.
description:
    Provides access to system information and functionality
    to Lua scripts via Haskell'\''s `System` module.
    .
    Intended usage for this package is to preload it by adding
    the loader function to `package.preload`. Note that the
    Lua `package` library must have already been loaded before
    the loader can be added.
category: Foreign
abi: 2c438304372b01a1b132ebadaea49443
exposed: True
exposed-modules:
    Foreign.Lua.Module.System
hidden-modules: Foreign.Lua.Module.SystemUtils
import-dirs: /usr/lib/ghc-8.6.5/site-local/hslua-module-system-0.2.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/hslua-module-system-0.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hslua-module-system-0.2.1
hs-libraries: HShslua-module-system-0.2.1-HzvfcWKmaLTAidtbC4JDQV
depends:
    base-4.12.0.0 containers-0.6.0.1 directory-1.3.3.0
    exceptions-0.10.2-EJs0RkZsum56ksbfDqbl1F
    hslua-1.0.3.1-40ur5CE4aGD2qxUMUcaV3N
    temporary-1.3-CFCgitssjB1JHRoe7RSBPx
haddock-interfaces: /usr/share/doc/haskell-hslua-module-system/html/hslua-module-system.haddock
haddock-html: /usr/share/doc/haskell-hslua-module-system/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
